@@ -20,6 +20,9 @@ class KACLConfig:
         self.allowed_header_titles = self.__config.get("allowed_header_titles")
         self.allowed_version_sections = self.__config.get("allowed_version_sections")
         self.default_content = self.__config.get("default_content")
+        self.add_unreleased = self.__config.get("release", {}).get(
+            "add_unreleased", True
+        )
         self.git_tag_name = self.__config.get("git", {}).get("tag_name")
         self.git_tag_description = self.__config.get("git", {}).get("tag_description")
         self.changelog_file_path = self.__config.get("file")
