@@ -150,10 +150,11 @@ def add(ctx, section, message, modify, stash):
 
     kacl_changelog_content = kacl.dump(kacl_changelog)
     # if stashing is enabled, do not modify the changelog file
-    if modify and not stash:
-        with open(kacl_changelog.config.changelog_file_path, "w") as f:
-            f.write(kacl_changelog_content)
-        f.close()
+    if modify:
+        if not stash:
+            with open(kacl_changelog.config.changelog_file_path, "w") as f:
+                f.write(kacl_changelog_content)
+            f.close()
     else:
         click.echo(kacl_changelog_content)
 
