@@ -23,7 +23,7 @@ def extract_issue_ids(
         ids = []
         for pattern in search_patterns[key]:
             ids.extend(re.findall(pattern, (version.body())))
-        issue_ids[key] = ids
+        issue_ids[key] = list(set(ids))
     return issue_ids
 
 
