@@ -285,6 +285,31 @@ def test_release_major(tmp_path, snapshot):
         snapshot_directory(snapshot=snapshot, directory_path=project_root_path)
 
 
+@freeze_time("2023-01-01")
+def test_release_major_no_unreleased(tmp_path, snapshot):
+    runner = CliRunner()
+    resources_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data/")
+    changelog_file = os.path.join(resources_dir, "CHANGELOG_with_changes.md")
+
+    with runner.isolated_filesystem(temp_dir=tmp_path) as project_root_path:
+        shutil.copyfile(changelog_file, os.path.join(project_root_path, "CHANGELOG.md"))
+        result = runner.invoke(
+            cli,
+            [
+                "-c",
+                os.path.join(resources_dir, "no-unreleased-config.yml"),
+                "-f",
+                "CHANGELOG.md",
+                "release",
+                "major",
+                "-m",
+            ],
+            catch_exceptions=False,
+        )
+        assert result.exit_code == 0, result.output
+        snapshot_directory(snapshot=snapshot, directory_path=project_root_path)
+
+
 @freeze_time("2023-01-01")
 def test_release_custom(tmp_path, snapshot):
     runner = CliRunner()
@@ -308,6 +333,34 @@ def test_release_custom(tmp_path, snapshot):
         snapshot_directory(snapshot=snapshot, directory_path=project_root_path)
 
 
+@freeze_time("2023-01-01")
+def test_release_no_change(tmp_path, snapshot):
+    runner = CliRunner()
+    resources_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data/")
+    changelog_file = os.path.join(resources_dir, "CHANGELOG_without_changes.md")
+
+    with runner.isolated_filesystem(temp_dir=tmp_path) as project_root_path:
+        shutil.copyfile(changelog_file, os.path.join(project_root_path, "CHANGELOG.md"))
+        result = runner.invoke(
+            cli,
+            [
+                "-f",
+                "CHANGELOG.md",
+                "release",
+                "2.1.1",
+            ],
+            catch_exceptions=False,
+        )
+        assert result.exit_code == 1, result.output
+
+        result = runner.invoke(
+            cli,
+            ["-f", "CHANGELOG.md", "release", "2.1.1", "-m"],
+            catch_exceptions=False,
+        )
+        assert result.exit_code == 1, result.output
+
+
 @freeze_time("2023-01-01")
 def test_add_change_security(tmp_path, snapshot):
     runner = CliRunner()
